Commit 54ae052859a63058e41b925bfa028c1d66343c4b

Etienne Samson 2019-01-14T01:25:05

tests: fix test expectation mismatch

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
diff --git a/tests/iterator/workdir.c b/tests/iterator/workdir.c
index 889fcd6..87ac1e5 100644
--- a/tests/iterator/workdir.c
+++ b/tests/iterator/workdir.c
@@ -661,10 +661,10 @@ void test_iterator_workdir__filesystem_gunk(void)
 
 	cl_git_pass(git_iterator_for_filesystem(&i, "testrepo/.git/refs", NULL));
 
 	/* should only have 13 items, since we're not asking for trees to be
 	 * returned.  the goal of this test is simply to not crash.
 	 */
-	expect_iterator_items(i, 15, NULL, 15, NULL);
+	expect_iterator_items(i, 16, NULL, 15, NULL);
 	git_iterator_free(i);
 	git_buf_dispose(&parent);
 }
@@ -661,10 +661,10 @@ void test_iterator_workdir__filesystem_gunk(void)
 	cl_git_pass(git_iterator_for_filesystem(&i, "testrepo/.git/refs", NULL));
 
-	/* should only have 13 items, since we're not asking for trees to be
+	/* should only have 16 items, since we're not asking for trees to be
 	 * returned.  the goal of this test is simply to not crash.
 	 */